@@ -18,9 +18,9 @@ class Provider(GeoProvider):
     def local_latitude(self):
         latitudes = list(map(lambda t: int(t[0] * 10000000), self.poly))
         return Decimal(str(self.generator.random.randint(
-            min(latitudes), max(latitudes)) / 10000000.0)).quantize(Decimal('.000001'))
+            min(latitudes), max(latitudes)) / 10000000)).quantize(Decimal('.000001'))
 
     def local_longitude(self):
         longitudes = list(map(lambda t: int(t[1] * 10000000), self.poly))
         return Decimal(str(self.generator.random.randint(
-            min(longitudes), max(longitudes)) / 10000000.0)).quantize(Decimal('.000001'))
+            min(longitudes), max(longitudes)) / 10000000)).quantize(Decimal('.000001'))
