@@ -1,10 +1,8 @@
-# coding=utf-8
 """it_IT ssn provider (yields italian fiscal codes)"""
 
-from __future__ import unicode_literals
 from string import ascii_uppercase, digits
-from .. import Provider as SsnProvider
 
+from .. import Provider as SsnProvider
 
 ALPHANUMERICS = sorted(digits + ascii_uppercase)
 ALPHANUMERICS_DICT = {char: index for index, char in enumerate(ALPHANUMERICS)}
@@ -16,20 +14,31 @@ CHECKSUM_TABLE = (
 
 
 def checksum(value):
-    '''
+    """
     Calculates the checksum char used for the 16th char.
     Author: Vincenzo Palazzo
-    '''
+    """
     return chr(65 + sum(CHECKSUM_TABLE[index % 2][ALPHANUMERICS_DICT[char]]
                         for index, char in enumerate(value)) % 26)
 
 
 class Provider(SsnProvider):
-    '''
+    """
     Generates italian fiscal codes.
-    '''
+    """
     fiscal_code_format = '??????##?##?###'
 
     def ssn(self):
         code = self.bothify(self.fiscal_code_format).upper()
         return code + checksum(code)
+
+    vat_id_formats = (
+        'IT###########',
+    )
+
+    def vat_id(self):
+        """
+        http://ec.europa.eu/taxation_customs/vies/faq.html#item_11
+        :return: A random Italian VAT ID
+        """
+        return self.bothify(self.random_element(self.vat_id_formats))
